@@ -2,6 +2,7 @@ from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import WebDriverWait as Wait
 from selenium.webdriver.common.keys import Keys
+from selenium.webdriver.remote.webelement import WebElement
 from typing import Optional, Union
 import requests
 import json
@@ -77,7 +78,7 @@ class Actions():
         response = requests.get(url, headers=headers, verify=verifySSL)
         return response
 
-    def clear_input(self, by_type: By, by_value: str, timeout: Optional[int] = None, retry: Optional[int] = None) -> None:
+    def clear_input(self, by_type: By, by_value: str, timeout: Optional[int] = None) -> Union[str, bool]:
     
         """
         This method executes a clear if the element is found within a time range.
@@ -90,21 +91,15 @@ class Actions():
                 '//*[@class="element"]' for an element with class='element'
 
             timeout (Optional): Generates a error if can't locate the element in x seconds. (Standard timeout: 10 seconds).
-            retry (Optional): After logging the error, attempts X times again to locate the element, every try can generate a new error.
         """
         
-        while True:
-            try:
-                Wait(self.driver, timeout or self.timeout).until(EC.presence_of_element_located((by_type, by_value))).clear()
-                break
-            except Exception as e:
-                print(e)
-                if retry != None and retry > 0:
-                    retry -= 1
-                else:
-                    break
+        try:
+            Wait(self.driver, timeout or self.timeout).until(EC.presence_of_element_located((by_type, by_value))).clear()
+            return True
+        except Exception as e:
+            return f"Exception on element {by_value}, {e}"
 
-    def send_keys(self, by_type: By, by_value: str, keys_array: list[Union[str, Keys]], timeout: Optional[int] = None, retry: Optional[int] = None) -> None:
+    def send_keys(self, by_type: By, by_value: str, keys_array: list[Union[str, Keys]], timeout: Optional[int] = None) -> Union[str, bool]:
 
         """
         This method press the keys in the sent array if the element is found within a time range.
@@ -121,21 +116,15 @@ class Actions():
                 you can use selenium.webdriver.common.keys module to get the keys too.
 
             timeout (Optional): Generates a error if can't locate the element in x seconds. (Standard timeout: 10 seconds).
-            retry (Optional): After logging the error, attempts X times again to locate the element, every try can generate a new error.
         """
 
-        while True:
-            try:
-                Wait(self.driver, timeout or self.timeout).until(EC.visibility_of_element_located((by_type, by_value))).send_keys(keys_array)
-                break
-            except Exception as e:
-                print(e)
-                if retry != None and retry > 0:
-                    retry -= 1
-                else:
-                    break
+        try:
+            Wait(self.driver, timeout or self.timeout).until(EC.visibility_of_element_located((by_type, by_value))).send_keys(keys_array)
+            return True
+        except Exception as e:
+            return f"Exception on element {by_value}, {e}"
 
-    def switch_to_frame(self, by_type: By, by_value: str, timeout: Optional[int] = None, retry: Optional[int] = None) -> None:
+    def switch_to_frame(self, by_type: By, by_value: str, timeout: Optional[int] = None) -> Union[str, bool]:
 
         """
         This method switches to the frame if the element is found within a time range.
@@ -148,19 +137,13 @@ class Actions():
                 '//*[@class="element"]' for an element with class='element'
 
             timeout (Optional): Generates a error if can't locate the element in x seconds. (Standard timeout: 10 seconds).
-            retry (Optional): After logging the error, attempts X times again to locate the element, every try can generate a new error.
         """
 
-        while True:
-            try:
-                Wait(self.driver, timeout or self.timeout).until(EC.frame_to_be_available_and_switch_to_it((by_type, by_value)))
-                break
-            except Exception as e:
-                print(e)
-                if retry != None and retry > 0:
-                    retry -= 1
-                else:
-                    break
+        try:
+            Wait(self.driver, timeout or self.timeout).until(EC.frame_to_be_available_and_switch_to_it((by_type, by_value)))
+            return True
+        except Exception as e:
+            return f"Exception on element {by_value}, {e}"
     
     def find_and_get_attribute(self, by_type: By, by_value: str, attribute: str, timeout: Optional[int] = None) -> Union[str, bool]:
 
@@ -184,5 +167,26 @@ class Actions():
         try:
             value = Wait(self.driver, timeout or self.timeout).until(EC.visibility_of_element_located((by_type, by_value))).get_attribute(attribute)
             return value
+        except Exception as e:
+            return False
+    
+    def find_element(self, by_type: By, by_value: str, timeout: Optional[int] = None) -> Union[WebElement, bool]:
+
+        """
+        This method finds the element if the element is found within a time range and returns the attribute value.
+
+        Arguments:
+            by_type: one of the By class constants, you can find them in selenium.webdriver.common.by module.
+
+            by_value: the value of the element to be clicked, for example:
+                '//*[@id="element"]' for an element with id='element'
+                '//*[@class="element"]' for an element with class='element'
+
+            timeout (Optional): Generates a error if can't locate the element in x seconds. (Standard timeout: 10 seconds).
+        """
+
+        try:
+            element = Wait(self.driver, timeout or self.timeout).until(EC.visibility_of_element_located((by_type, by_value)))
+            return element
         except Exception as e:
             return False
\ No newline at end of file
